==> haskell-czipwith-1.0.1.4-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-czipwith.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 czipwith
version:              1.0.1.4
visibility:           public
id:                   czipwith-1.0.1.4-4sOOcAhbcpOHCCcoX3HddX
key:                  czipwith-1.0.1.4-4sOOcAhbcpOHCCcoX3HddX
license:              BSD-3-Clause
copyright:            Copyright (C) 2017-2020 Lennart Spitzner
maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
homepage:             https://github.com/lspitzner/czipwith/
synopsis:             CZipWith class and deriving via TH
description:
    A typeclass similar to Data.Distributive, but for
    data parameterised with a type constructor. The name
    comes from the resemblance of its method to the regular
    zipWith function. The abstraction is useful for example
    for program config handling.

category:             Data
abi:                  802ee5c13102b67ef7b0c9639be7bc39
exposed:              True
exposed-modules:      Data.CZipWith
import-dirs:          /usr/lib/ghc-9.0.1/site-local/czipwith-1.0.1.4
library-dirs:         /usr/lib/ghc-9.0.1/site-local/czipwith-1.0.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/czipwith-1.0.1.4
hs-libraries:         HSczipwith-1.0.1.4-4sOOcAhbcpOHCCcoX3HddX
depends:              base-4.15.0.0 template-haskell-2.17.0.0
haddock-interfaces:   /usr/share/doc/haskell-czipwith/html/czipwith.haddock
haddock-html:         /usr/share/doc/haskell-czipwith/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-czipwith-1.0.1.4-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-czipwith.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 czipwith
version:              1.0.1.4
visibility:           public
id:                   czipwith-1.0.1.4-EXJR4bf7ZgFBXkogwUHX2e
key:                  czipwith-1.0.1.4-EXJR4bf7ZgFBXkogwUHX2e
license:              BSD-3-Clause
copyright:            Copyright (C) 2017-2020 Lennart Spitzner
maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
homepage:             https://github.com/lspitzner/czipwith/
synopsis:             CZipWith class and deriving via TH
description:
    A typeclass similar to Data.Distributive, but for
    data parameterised with a type constructor. The name
    comes from the resemblance of its method to the regular
    zipWith function. The abstraction is useful for example
    for program config handling.

category:             Data
abi:                  5da76ca49273bb8939a00593ca126ca0
exposed:              True
exposed-modules:      Data.CZipWith
import-dirs:          /usr/lib/ghc-9.0.2/site-local/czipwith-1.0.1.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/czipwith-1.0.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/czipwith-1.0.1.4
hs-libraries:         HSczipwith-1.0.1.4-EXJR4bf7ZgFBXkogwUHX2e
depends:              base-4.15.1.0 template-haskell-2.17.0.0
haddock-interfaces:   /usr/share/doc/haskell-czipwith/html/czipwith.haddock
haddock-html:         /usr/share/doc/haskell-czipwith/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
